;; Generated package description from polymode.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "polymode" "0.2.2.0.20260505.180301" "Extensible framework for multiple major modes" '((emacs "25")) :commit "8cb72fa5dcc0d98746c680043dc121edc7621e3a" :maintainer '("Vitalie Spinu" . "spinuvit@gmail.com") :keywords '("languages" "multi-modes" "processes") :url "https://github.com/polymode/polymode")
